@@ -14,7 +14,7 @@ def autolink_tests(tests, passed, failed):
     correct_auto_link_usernames_or_lists = u'<a class="tweet-url username" href="http://twitter.com/foo" rel="nofollow">@foo</a> said the funniest thing to <a class="tweet-url username" href="http://twitter.com/monkeybat" rel="nofollow">＠monkeybat</a> and <a class="tweet-url username" href="http://twitter.com/bar" rel="nofollow">@bar</a> http://dryan.net/xxxxx?param=true#hash #comedy #url'
     correct_auto_link_hashtags = u'@foo said the funniest thing to ＠monkeybat and @bar http://dryan.net/xxxxx?param=true#hash <a href="http://twitter.com/search?q=%23comedy" title="#comedy" class="tweet-url hashtag" rel="nofollow">#comedy</a> <a href="http://twitter.com/search?q=%23url" title="#url" class="tweet-url hashtag" rel="nofollow">#url</a>'
     correct_auto_link_urls_custom = u'@foo said the funniest thing to ＠monkeybat and @bar <a href="http://dryan.net/xxxxx?param=true#hash" rel="nofollow">http://dryan.net/xxxxx?param=t…</a> #comedy #url'
-    correct_auto_link_urls_custom_with_kwargs = u'@foo said the funniest thing to ＠monkeybat and @bar <a href="http://dryan.net/xxxxx?param=true#hash" class="boosh" rel="external nofollow" title="a link">http://dryan.net/xxxxx?param=t…</a> #comedy #url'
+    correct_auto_link_urls_custom_with_kwargs = u'@foo said the funniest thing to ＠monkeybat and @bar <a href="http://dryan.net/xxxxx?param=true#hash" class="boosh" rel="external" title="a link">http://dryan.net/xxxxx?param=t…</a> #comedy #url'
 
     autolink = twitter_text.Autolink(text)
 
@@ -153,12 +153,12 @@ def extractor_tests(tests, passed, failed):
     print u'Running Extractor tests'
 
     correct_mentioned_screen_names = [u'foo', u'monkeybat', u'bar']
-    correct_mentioned_screen_names_with_indices = [{'indicies': (1, 4), 'screen_name': u'foo'}, {'indicies': (33, 42), 'screen_name': u'monkeybat'}, {'indicies': (48, 51), 'screen_name': u'bar'}]
+    correct_mentioned_screen_names_with_indices = [{'indices': (0, 4), 'screen_name': u'foo'}, {'indices': (32, 42), 'screen_name': u'monkeybat'}, {'indices': (47, 51), 'screen_name': u'bar'}]
     correct_reply_screen_name = 'foo'
     correct_urls = [u'http://dryan.net/xxxxx?param=true#hash']
     correct_urls_with_indices = [{'url': u'http://dryan.net/xxxxx?param=true#hash', 'indices': (52, 90)}]
     correct_hashtags = [u'comedy', u'url']
-    correct_hashtags_with_indices = [{'indices': (92, 98), 'hashtag': u'comedy'}, {'indices': (100, 103), 'hashtag': u'url'}]
+    correct_hashtags_with_indices = [{'indices': (91, 98), 'hashtag': u'comedy'}, {'indices': (99, 103), 'hashtag': u'url'}]
 
     extractor = twitter_text.Extractor(text)
     
@@ -427,6 +427,35 @@ def validation_tests(tests, passed, failed):
     tests += 1
     
     return tests, passed, failed
+    
+def templatetag_tests(tests, passed, failed):
+    print u'Running Django templatetag tests'
+    from twitter_text.templatetags import twitterize
+
+    correct_auto_link = u'<a class="tweet-url username" href="http://twitter.com/foo" rel="nofollow">@foo</a> said the funniest thing to <a class="tweet-url username" href="http://twitter.com/monkeybat" rel="nofollow">＠monkeybat</a> and <a class="tweet-url username" href="http://twitter.com/bar" rel="nofollow">@bar</a> <a href="http://dryan.net/xxxxx?param=true#hash" rel="nofollow">http://dryan.net/xxxxx?param=t…</a> <a href="http://twitter.com/search?q=%23comedy" title="#comedy" class="tweet-url hashtag" rel="nofollow">#comedy</a> <a href="http://twitter.com/search?q=%23url" title="#url" class="tweet-url hashtag" rel="nofollow">#url</a>'
+    correct_auto_link_with_hit_highlight = u'<a class="tweet-url username" href="http://twitter.com/foo" rel="nofollow">@foo</a> said the <em class="search-hit">funniest</em> thing to <a class="tweet-url username" href="http://twitter.com/monkeybat" rel="nofollow">＠monkeybat</a> and <a class="tweet-url username" href="http://twitter.com/bar" rel="nofollow">@bar</a> <a href="http://dryan.net/xxxxx?param=true#hash" rel="nofollow">http://dryan.net/xxxxx?param=t…</a> <a href="http://twitter.com/search?q=%23comedy" title="#comedy" class="tweet-url hashtag" rel="nofollow">#comedy</a> <a href="http://twitter.com/search?q=%23url" title="#url" class="tweet-url hashtag" rel="nofollow">#url</a>'
+    
+    if twitterize.twitter_text(text) == correct_auto_link:
+        print u'\033[92m  Django templatetag with no search term passed\033[0m'
+        passed += 1
+    else:
+        print u'\033[91m  Django templatetag with no search term failed:\033[0m'
+        print u'    Expected: %s' % correct_auto_link
+        print u'    Returned: %s' % twitterize.twitter_text(text)
+        failed += 1
+    tests += 1
+
+    if twitterize.twitter_text(text, 'funniest') == correct_auto_link_with_hit_highlight:
+        print u'\033[92m  Django templatetag with search term passed\033[0m'
+        passed += 1
+    else:
+        print u'\033[91m  Django templatetag with search term failed:\033[0m'
+        print u'    Expected: %s' % correct_auto_link_with_hit_highlight
+        print u'    Returned: %s' % twitterize.twitter_text(text, 'funniest')
+        failed += 1
+    tests += 1
+    
+    return tests, passed, failed
 
 def run_all():
     tests, passed, failed = 0, 0, 0
@@ -442,6 +471,9 @@ def run_all():
     print ''
     tests, passed, failed = autolink_tests(tests, passed, failed)
 
+    print ''
+    tests, passed, failed = templatetag_tests(tests, passed, failed)
+
     print ''
     print u'Checking hit_highlight assertion that text does not have HTML tags already present'
     try:
